@@ -44,7 +44,7 @@ private:
     void initializeWizard();
     void slotHelpClicked();
     void slotFinishImportData();
-    void slotNoSettingsFound(const QString &name);
+    void slotAddSummaryInfo(const QString &name);
     QMap<QString, AbstractImapSettingsCheckJob *> mListCheckJob;
 
     ImportImapSettingSearchPage *mSearchPage;
