@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -40,7 +40,7 @@ ServerSieveListWidget::~ServerSieveListWidget()
 void ServerSieveListWidget::readConfig()
 {
     const QVector<SieveEditorUtil::SieveServerConfig> lstServer = SieveEditorUtil::readServerSieveConfig();
-    Q_FOREACH (const SieveEditorUtil::SieveServerConfig &conf, lstServer) {
+    for (const SieveEditorUtil::SieveServerConfig &conf : lstServer) {
         ServerSieveListWidgetItem *item = new ServerSieveListWidgetItem(this);
         item->setServerConfig(conf);
     }
@@ -58,6 +58,7 @@ void ServerSieveListWidget::writeConfig()
         }
     }
     SieveEditorUtil::writeServerSieveConfig(lstServerConfig);
+    SieveEditorUtil::deletePasswords(mNeedToRemovePasswordInWallet);
 }
 
 void ServerSieveListWidget::modifyServerConfig()
@@ -78,6 +79,18 @@ void ServerSieveListWidget::modifyServerConfig()
     delete dlg;
 }
 
+void ServerSieveListWidget::deleteServerConfig(QListWidgetItem *item)
+{
+    ServerSieveListWidgetItem *serverSieveListItem = static_cast<ServerSieveListWidgetItem *>(item);
+    SieveEditorUtil::SieveServerConfig conf = serverSieveListItem->serverConfig();
+
+    mNeedToRemovePasswordInWallet.append(SieveEditorUtil::sievePasswordIdentifier(conf.sieveSettings.userName, conf.sieveSettings.serverName));
+    const QString imapIdentifier = SieveEditorUtil::imapPasswordIdentifier(conf.sieveImapAccountSettings.userName(), conf.sieveImapAccountSettings.serverName());
+    if (!imapIdentifier.isEmpty()) {
+        mNeedToRemovePasswordInWallet.append(imapIdentifier);
+    }
+}
+
 void ServerSieveListWidget::addServerConfig()
 {
     QPointer<ServerSieveSettingsDialog> dlg = new ServerSieveSettingsDialog(this);
@@ -107,6 +120,6 @@ SieveEditorUtil::SieveServerConfig ServerSieveListWidgetItem::serverConfig() con
 void ServerSieveListWidgetItem::setServerConfig(const SieveEditorUtil::SieveServerConfig &conf)
 {
     setCheckState(conf.enabled ? Qt::Checked : Qt::Unchecked);
-    setText(i18nc("server name (username)", "%1 (%2)", conf.serverName, conf.userName));
+    setText(i18nc("server name (username)", "%1 (%2)", conf.sieveSettings.serverName, conf.sieveSettings.userName));
     mServerConfig = conf;
 }
