@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ class SieveEditorBookmarks : public QObject, public KBookmarkOwner
 {
     Q_OBJECT
 public:
-    explicit SieveEditorBookmarks(SieveEditorMainWindow *mainWindow, KActionCollection *collection, QMenu *menu, QObject *parent = Q_NULLPTR);
+    explicit SieveEditorBookmarks(SieveEditorMainWindow *mainWindow, KActionCollection *collection, QMenu *menu, QObject *parent = nullptr);
     ~SieveEditorBookmarks();
 
     QMenu *menu() const;
