@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -54,14 +54,14 @@ void SieveEditorScriptManagerWidget::slotUpdateButtons(QTreeWidgetItem *item)
     Q_EMIT updateButtons(newScriptAction, editScriptAction, deleteScriptAction, desactivateScriptAction);
 }
 
-void SieveEditorScriptManagerWidget::slotEditScript(const QUrl &url, const QStringList &capabilities)
+void SieveEditorScriptManagerWidget::slotEditScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
 {
-    Q_EMIT createScriptPage(url, capabilities, false);
+    Q_EMIT createScriptPage(url, capabilities, false, sieveImapAccountSettings);
 }
 
-void SieveEditorScriptManagerWidget::slotNewScript(const QUrl &url, const QStringList &capabilities)
+void SieveEditorScriptManagerWidget::slotNewScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
 {
-    Q_EMIT createScriptPage(url, capabilities, true);
+    Q_EMIT createScriptPage(url, capabilities, true, sieveImapAccountSettings);
 }
 
 void SieveEditorScriptManagerWidget::slotCreateNewScript()
